Source-Changes-HG archive
[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]
[src/trunk]: src/sys/dev/pci Fix spello.
details: https://anonhg.NetBSD.org/src/rev/091bdba4e5fd
branches: trunk
changeset: 584307:091bdba4e5fd
user: skrll <skrll%NetBSD.org@localhost>
date: Mon Sep 12 21:15:04 2005 +0000
description:
Fix spello.
diffstat:
sys/dev/pci/if_iwi.c | 10 +++++-----
sys/dev/pci/if_iwireg.h | 4 ++--
2 files changed, 7 insertions(+), 7 deletions(-)
diffs (53 lines):
diff -r b2eb4bb69f5c -r 091bdba4e5fd sys/dev/pci/if_iwireg.h
--- a/sys/dev/pci/if_iwireg.h Mon Sep 12 21:11:11 2005 +0000
+++ b/sys/dev/pci/if_iwireg.h Mon Sep 12 21:15:04 2005 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: if_iwireg.h,v 1.5 2005/08/19 08:50:06 skrll Exp $ */
+/* $NetBSD: if_iwireg.h,v 1.6 2005/09/12 21:15:04 skrll Exp $ */
/*-
* Copyright (c) 2004, 2005
@@ -272,7 +272,7 @@
u_int8_t mode;
u_int8_t nrates;
u_int8_t type;
-#define IWI_RATESET_TYPE_NEGOCIATED 0
+#define IWI_RATESET_TYPE_NEGOTIATED 0
#define IWI_RATESET_TYPE_SUPPORTED 1
u_int8_t reserved;
u_int8_t rates[12];
Home |
Main Index |
Thread Index |
Old Index
diff -r b2eb4bb69f5c -r 091bdba4e5fd sys/dev/pci/if_iwi.c
--- a/sys/dev/pci/if_iwi.c Mon Sep 12 21:11:11 2005 +0000
+++ b/sys/dev/pci/if_iwi.c Mon Sep 12 21:15:04 2005 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: if_iwi.c,v 1.21 2005/09/12 21:11:11 skrll Exp $ */
+/* $NetBSD: if_iwi.c,v 1.22 2005/09/12 21:15:04 skrll Exp $ */
/*-
* Copyright (c) 2004, 2005
@@ -28,7 +28,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: if_iwi.c,v 1.21 2005/09/12 21:11:11 skrll Exp $");
+__KERNEL_RCSID(0, "$NetBSD: if_iwi.c,v 1.22 2005/09/12 21:15:04 skrll Exp $");
/*-
* Intel(R) PRO/Wireless 2200BG/2225BG/2915ABG driver
@@ -2184,13 +2184,13 @@
if (error != 0)
return error;
/* the rate set has already been "negociated" */
rs.mode = IEEE80211_IS_CHAN_5GHZ(ni->ni_chan) ? IWI_MODE_11A :
IWI_MODE_11G;
- rs.type = IWI_RATESET_TYPE_NEGOCIATED;
+ rs.type = IWI_RATESET_TYPE_NEGOTIATED;
rs.nrates = ni->ni_rates.rs_nrates;
memcpy(rs.rates, ni->ni_rates.rs_rates, rs.nrates);
- DPRINTF(("Setting negociated rates (%u)\n", rs.nrates));
+ DPRINTF(("Setting negotiated rates (%u)\n", rs.nrates));
error = iwi_cmd(sc, IWI_CMD_SET_RATES, &rs, sizeof rs, 1);
if (error != 0)
return error;
@@ -2184,13 +2184,13 @@
if (error != 0)
return error;
- /* the rate set has already been "negociated" */
+ /* the rate set has already been "negotiated" */
rs.mode = IEEE80211_IS_CHAN_5GHZ(ni->ni_chan) ? IWI_MODE_11A :
IWI_MODE_11G;